@@ -1,6 +1,5 @@
 import pkg_resources
 
-#logging.basicConfig(level=logging.ERROR)
 
 try:
     version = pkg_resources.require("rtools")[0].version
@@ -17,7 +16,7 @@ try:
     import colormap
     from colormap import *
 except ImportError, e:
-    logging.warning("colormap module will not work (could not import a package. pylab maybe ?)")
+    print("colormap module will not work (could not import a package. pylab maybe ?)")
 
 import tools
 from tools import *
