@@ -13,7 +13,7 @@
 #  RTools website: http://www.ebi.ac.uk/~cokelaer/rtools
 #
 ##############################################################################
-# $Id: tools.py 2 2013-01-25 13:25:10Z cokelaer $
+# $Id: tools.py 7 2013-02-04 13:51:20Z cokelaer $
 """Utilities for cnolab.wrapper
 
 :author: Thomas Cokelaer <cokelaer@ebi.ac.uk>
@@ -26,7 +26,6 @@ __author__ = """\n""".join(['Thomas Cokelaer <cokelaer@ebi.ac.uk'])
 __all__ = ['Rnames2attributes',  'buildDocString', "RManualToDocString",  
      "RConvertor", "convertor", "rcode"]
 
-import logging
 import os
 import rpy2
 from rpy2 import robjects
@@ -202,6 +201,7 @@ class RManualToDocString(object):
         'references', 'seealso', 'examples', 'keyword']
 
     def __init__(self, package, funcname):
+        #print("Processing %s %s" % (package, funcname))
         from rpy2 import robjects
         from rpy2.robjects.help import HelpNotFoundError
         self.name = funcname
@@ -218,7 +218,8 @@ class RManualToDocString(object):
 
     def _get_section(self, section):
         if section not in RManualToDocString.registered_sections:
-            print("section %s not known. Skip it. Fix RManualToDocString class please.\n" % section)
+            print("section (%s) not known in %s. Skip it. Fix\
+                RManualToDocString class please.\n" % (self.name, section))
         self._temp = []
         self._walk(self.doc.sections[section], section)
         return self._temp
