@@ -1,12 +1,13 @@
 from rtools.package import *
 import unittest
 
-@unittest.skip
+#@unittest.skip
 def test_install_package():
-    install_packages("truncnorm")
+    #install_packages("truncnorm")
+    install_packages("truncnorm", repos=RPackageManager.cran_repos)
 
 
-@unittest.skip
+#@unittest.skip
 def test_biocLite():
     biocLite("truncnorm")
 
@@ -14,7 +15,6 @@ def test_Rpackage():
 
     r = RPackage("base")
     r.version
-    r.load()
 
 
     # load a non-existing package 
@@ -27,3 +27,8 @@ def test_Rpackage():
     r = RPackage("base", require="10000.0")
     assert r.package == None
 
+
+def test_RPM():
+    r = RPackageManager()
+    r.install_packages("base")
+    assert r.require("base", "1.0") == True
